@@ -55,15 +55,16 @@ def generate_file(graph):
                 steps_list[(graph['nodes'][j]['data']['name'])]=graph['nodes'][j]['data']['node_type']
 
     for i in steps_list:
-        if steps_list[i]=='preprocess':
-            print(preprocess_generate([i]))
-        elif steps_list[i] == 'model':
-            print(train_generate([i]))
-        elif steps_list[i] == 'essential':
-            print(i)
-        elif steps_list[i] == 'evalauate_model':
-            print(i)
-    
+        for node in graph['nodes']:
+            if i == node['data']['name']:
+                if steps_list[i]=='preprocess':
+                    script = preprocess_generate(node)
+                elif steps_list[i] == 'model':
+                    script = train_generate(node)
+                elif steps_list[i] == 'essential':
+                    script = "eeekjschj"
+                elif steps_list[i] == 'evalauate_model':
+                    script = "evaluate model"
 
 
 
